@@ -1795,11 +1795,11 @@ static bool test_pthread_talloc_passing(void)
 	 * They will use their own toplevel contexts.
 	 */
 	for (i = 0; i < NUM_THREADS; i++) {
-		(void)snprintf(str_array[i],
-				20,
-				"thread:%d",
-				i);
-		if (str_array[i] == NULL) {
+		ret = snprintf(str_array[i],
+			       20,
+			       "thread:%d",
+			       i);
+		if (ret < 0) {
 			printf("snprintf %d failed\n", i);
 			return false;
 		}
@@ -1895,10 +1895,13 @@ static bool test_magic_protection(void)
 
 		/* Then the attack takes effect when the memory's freed. */
 		talloc_free(pool);
-	} else {
-		while (wait(&exit_status) != pid);
+
+		/* Never reached. Make compilers happy */
+		return true;
 	}
 
+	while (wait(&exit_status) != pid);
+
 	if (!WIFEXITED(exit_status)) {
 		printf("Child exited through unexpected abnormal means\n");
 		return false;
